/****************************************************************************/
/* void read_script(const char *param_file_name, bool rd_lat)

   Purpose:
       read script written by the user.
       1) User can specify lattice file name, vacuum chamber name, and bool flags such as tune 
          tracking flag, tune shift with energy flag, etc.
       2) In this function, Lattice is read, bool flags are set. 

   Input:
       param_file_name  user script name

   Output:
       none

   Return:
       global values and global bool flags 

   Global variables:
       bool flags

   specific functions:
       Read_Lattice()

   Comments:
       Written by Jianfeng Zhang 03/2011 soleil

****************************************************************************/

/* files */ 

// girder file
char girder_file[max_str];



 // multipole files; for soleil lattice
char multipole_file[max_str];
  // multipole file for soleil lattice 
char fic_hcorr[max_str],fic_vcorr[max_str], fic_skew[max_str];
 // files to set sources of coupling; for SOLEIL lattice
char virtualskewquad_file[max_str];

//errors
//char fe_file[max_str]; //the same as multipole_file[max_str]????

/* COD correction */
int nwh = 56, nwv = 56; //number of singular values for SVD correction

/* ID compensation */  
char   IDCq_name[max_str][11];


//multipole field error correction (SOLEIL based)
char hcorr_file[max_str], vcorr_file[max_str]; //files with the status of hcorr/vcorr status, 
                                                  //to choose which correctors are used for orbit correction
//default name of special elements in lattice
char hcorr_name[max_str] = "", vcorr_name[max_str] = "";
char skew_quad_name[max_str] = "", bpm_name[max_str] = "";
char gs_name[max_str] = "", ge_name[max_str] = "";
						  
#define OLD_LATTICE

/*  Read script   */
void read_script(const char *param_file_name, bool rd_lat, long& CommNo, UserCommand UserCommandFlag[])
 {
 
  
  char    str[max_str]="voidstring", dummy[max_str]="voidstring", nextpara[max_str]="voidpara";
  char    in[max_str];  //temporary line with preceding white space
  char    *line; //line to store the command without preceding white space
  char    name[max_str]="voidname";
  char    lat_file[max_str]="voidlattice";
  char    EndName[]="void";
 
  FILE    *inf;
  const bool  prt = false; // for debugging printout each line of input file
  long int    LineNum=0L;
  long int    NameLen=0L;
  int idummy=0;
  char full_param_file_name[max_str];
  char lat_FileName[max_str];
 //bool TuneTracFlag;
  char *pch;
  
    
  // Manipulation of the parameter file
  strcpy(dummy, param_file_name);
  pch = strstr (dummy,".prm"); // search for extension .prm
  /* remove additional .prm if exist */
  if (pch != NULL) strncpy(pch,"\0",1);

  sprintf(full_param_file_name,"%s.prm",dummy);
  if (prt) printf("\n reading in script file: %s\n",full_param_file_name);

  //
  inf = file_read(full_param_file_name);

  
  // read parameter file, line by line 
 //  while (fgets(line, max_str, inf) != NULL) {
   while (line = fgets(in, max_str, inf)) {
   
     /* kill preceding whitespace generated by "table" key
        or "space" key, but leave \n 
        so we're guaranteed to have something*/
     while(*line == ' ' || *line == '\t') {
       line++;
     }       
    
    if(prt)
      printf("cfg: %s",line);
      
      LineNum++;
           
    /* read the end of line symbol '\n','\r' or '\r\n' at different operation system*/
    if (strstr(line, "#") == NULL && strcmp(line,"\n") != 0 &&
        strcmp(line,"\r") != 0 && strcmp(line,"\r\n") != 0) {
      // get initial command token
      sscanf(line, "%s", name); 
      //initialize the nextpara for each new command line
      strcpy(nextpara,"voidpara");
      
      
      //find the sequence of the bool flag in user input script 
      NameLen = strlen(name);
      EndName[0] = name[NameLen-4];
      EndName[1] = name[NameLen-3];
      EndName[2] = name[NameLen-2];
      EndName[3] = name[NameLen-1];          
      
      //find the bool flag whose last 4 character are 'Flag' 
      if(strcmp(EndName,"Flag")==0)
           CommNo++;
        
         
      /*read file names................. */
      /* set file directory*/
      if (strcmp("in_dir", name) == 0)
        sscanf(line, "%*s %s", in_dir);
      /* lattice file......*/
      else if (strcmp("lat_file", name) == 0){ 
        sscanf(line, "%*s %s", lat_file);
        sprintf(lat_FileName, "%s%s", in_dir, lat_file); 
        if(rd_lat) {
         #ifdef OLD_LATTICE
            fprintf(stderr, "Reading lattice");
            Read_Lattice(lat_FileName);
         #else
 /*           fprintf(stderr, "Reading lattice with new parser\n");
            sprintf(lat_FileName, "%s%s.lat", in_dir, lat_file);
            parse_lattice_flat(lat_FileName, "new.flat");
            fprintf(stderr, "Parse the lattice into new.flat\n");
            rdmfile("new.flat");
            sprintf(lat_FileName, "%s%s", in_dir, lat_file);
*/
         #endif
        }  
      
      } 
      
      /* other file names.....*/ 
      else if (strcmp("multipole_file", name) == 0){ 
        sscanf(line, "%*s %s", str);
        sprintf(multipole_file,"%s%s", in_dir, str); /* add file directory of the multipole file*/
      } //virtual skew quadrupole file; for soleil lattice
        else if (strcmp("virtualskewquad_file", name) == 0){ 
        sscanf(line, "%*s %s", str);
        sprintf(virtualskewquad_file,"%s%s", in_dir, str); /* add file directory of the multipole file*/
      } 
      
      /* read in bool flags */
        else if (strcmp("QuadFringeOnFlag", name) == 0){
	  strcpy(UserCommandFlag[CommNo].CommandStr,name);
      } 
        else if (strcmp("QuadFringeOffFlag", name) == 0){
	  strcpy(UserCommandFlag[CommNo].CommandStr,name);
      } 
        else if (strcmp("RFvoltageFlag", name) == 0){
	  sscanf(line, "%*s %lf", &(UserCommandFlag[CommNo].RFvolt));
	  strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }
        
      //read chamber file flat
      else if (strcmp("ReadChamberFlag", name) == 0){
 	  sscanf(line, "%*s %s", str);
	  sprintf(UserCommandFlag[CommNo].chamber_file,"%s%s", in_dir, str);
	  strcpy(UserCommandFlag[CommNo].CommandStr,name);
       } 
       //read field error, GENERIC command
      else if (strcmp("ReadfefileFlag", name) == 0){
 	  sscanf(line, "%*s %s", str);
	  sprintf(UserCommandFlag[CommNo].fe_file,"%s%s", in_dir, str);
	  strcpy(UserCommandFlag[CommNo].CommandStr,name);
       }     
       //read misalignment error, then do orbit correction
      else if (strcmp("ReadaefileFlag", name) == 0){
          sscanf(line, "%*s %s", str);
	  sprintf(UserCommandFlag[CommNo].ae_file,"%s%s", in_dir, str);
	  strcpy(UserCommandFlag[CommNo].CommandStr,name);
       } 
      //read multipole errors; specific for SOLEIL lattice
      else if (strcmp("ReadMultipoleFlag", name) == 0){
            strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }else if (strcmp("fic_hcorr", name) == 0){// read of h-correctors for multipoles
        sscanf(line, "%*s %s", str);
        sprintf(fic_hcorr,"%s%s", in_dir, str);
      }else if (strcmp("fic_vcorr", name) == 0){// read of v-correctors for multipoles
        sscanf(line, "%*s %s", str);
        sprintf(fic_vcorr,"%s%s", in_dir, str);
      }else if (strcmp("fic_skew", name) == 0){// read of skew quads for multipoles
        sscanf(line, "%*s %s", str);
        sprintf(fic_skew,"%s%s", in_dir, str);
      }
      // for soleil lattice
      else if (strcmp("ReadVirtualSkewquadFlag", name) == 0){
            strcpy(UserCommandFlag[CommNo].CommandStr,name);  
      }
       //print twiss parameters flag
      else if (strcmp("PrintTwissFlag", name) == 0){
         sscanf(line, "%*s %s",nextpara);
	 
	  if(strcmp(nextpara,"voidpara")!=0)
            sscanf(line, "%*s %s", UserCommandFlag[CommNo]._PrintTwiss_twiss_file);
	    
	  strcpy(UserCommandFlag[CommNo].CommandStr,name);
      } 
       //print close orbit(COD) flag
      else if (strcmp("PrintCODFlag", name) == 0){
        sscanf(line, "%*s %s",nextpara);
	 
	if(strcmp(nextpara,"voidpara")!=0)
           sscanf(line, "%*s %s", UserCommandFlag[CommNo]._PrintCOD_cod_file);
          
	strcpy(UserCommandFlag[CommNo].CommandStr,name);  
      }
      //print the cooridinates using tracking at each element
      else if (strcmp("PrintTrackFlag", name) == 0){
	  sscanf(line, "%*s %s",nextpara);
	 
	  if(strcmp(nextpara,"voidpara")!=0)
	    sscanf(line, "%*s %s %lf %lf %lf %lf %lf %lf %ld", 
	                UserCommandFlag[CommNo]._PrintTrack_track_file,
          		&(UserCommandFlag[CommNo]._PrintTrack_x), 
			&(UserCommandFlag[CommNo]._PrintTrack_px),
          		&(UserCommandFlag[CommNo]._PrintTrack_y), 
			&(UserCommandFlag[CommNo]._PrintTrack_py), 
			&(UserCommandFlag[CommNo]._PrintTrack_delta), 
			&(UserCommandFlag[CommNo]._PrintTrack_ctau),
			&(UserCommandFlag[CommNo]._PrintTrack_nmax));
	  strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }  
      //print close orbit(COD) flag
      else if (strcmp("PrintGirderFlag", name) == 0){
          sscanf(line, "%*s %s", girder_file);
	  strcpy(UserCommandFlag[CommNo].CommandStr,name);  
      }
      
      
      else if (strcmp("TuneTracFlag", name) == 0){
	 strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }
      else if (strcmp("ChromTracFlag", name) == 0){
	   strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }
      // FMA
      else if (strcmp("FmapFlag", name) == 0){        
    	  strcpy(dummy, "");
	  
	  sscanf(line, "%*s %s",nextpara);
	 
	  if(strcmp(nextpara,"voidpara")!=0)
            sscanf(line, "%*s %s %ld %ld %ld %lf %lf %lf %s", 
              		  UserCommandFlag[CommNo]._FmapFlag_fmap_file,
			  &(UserCommandFlag[CommNo]._FmapFlag_nxpoint), 
			  &(UserCommandFlag[CommNo]._FmapFlag_nypoint),
          		  &(UserCommandFlag[CommNo]._FmapFlag_nturn), 
			  &(UserCommandFlag[CommNo]._FmapFlag_xmax), 
			  &(UserCommandFlag[CommNo]._FmapFlag_ymax),
          		  &(UserCommandFlag[CommNo]._FmapFlag_delta), 
			  dummy);
         
        if(strcmp(dummy, "true") == 0)
          UserCommandFlag[CommNo]._FmapFlag_diffusion = true;
        else if(strcmp(dummy, "false") == 0)
          UserCommandFlag[CommNo]._FmapFlag_diffusion = false;
       
       // FmapFlag = true;
         strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }
      // FMA dp
      else if (strcmp("FmapdpFlag", name) == 0){         
    	  strcpy(dummy, "");
	  sscanf(line, "%*s %s",nextpara);
	 
	  if(strcmp(nextpara,"voidpara")!=0)
            sscanf(line, "%*s %s %ld %ld %ld %lf %lf %lf %s", 
          		UserCommandFlag[CommNo]._FmapdpFlag_fmapdp_file,
			&(UserCommandFlag[CommNo]._FmapdpFlag_nxpoint),
			&(UserCommandFlag[CommNo]._FmapdpFlag_nepoint),
          		&(UserCommandFlag[CommNo]._FmapdpFlag_nturn), 
			&(UserCommandFlag[CommNo]._FmapdpFlag_xmax), 
			&(UserCommandFlag[CommNo]._FmapdpFlag_emax),
          		&(UserCommandFlag[CommNo]._FmapdpFlag_z), 
			dummy);
	 
        if(strcmp(dummy, "true") == 0)
          UserCommandFlag[CommNo]._FmapdpFlag_diffusion = true;
        else if(strcmp(dummy, "false") == 0)
          UserCommandFlag[CommNo]._FmapdpFlag_diffusion = false;

	  //  FmapdpFlag = true;
         strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }
      else if (strcmp("AmplitudeTuneShiftFlag", name) == 0){
        sscanf(line, "%*s %s",nextpara);
	 
	if(strcmp(nextpara,"voidpara")!=0)   
          sscanf(line, "%*s %s %s %ld %ld %ld %lf %lf %lf", 
	          UserCommandFlag[CommNo]._AmplitudeTuneShift_nudx_file,
		  UserCommandFlag[CommNo]._AmplitudeTuneShift_nudz_file,
	         &(UserCommandFlag[CommNo]._AmplitudeTuneShift_nxpoint),
	         &(UserCommandFlag[CommNo]._AmplitudeTuneShift_nypoint), 
	         &(UserCommandFlag[CommNo]._AmplitudeTuneShift_nturn),
                 &(UserCommandFlag[CommNo]._AmplitudeTuneShift_xmax),
	         &(UserCommandFlag[CommNo]._AmplitudeTuneShift_ymax),
                 &(UserCommandFlag[CommNo]._AmplitudeTuneShift_delta));
       
       strcpy(UserCommandFlag[CommNo].CommandStr,name);    
      }
      else if (strcmp("EnergyTuneShiftFlag", name) == 0){
        sscanf(line, "%*s %s",nextpara);
	 
	 if(strcmp(nextpara,"voidpara")!=0)
	   sscanf(line, "%*s %s %ld %ld %lf",  
	          UserCommandFlag[CommNo]._EnergyTuneShift_nudp_file,
	         &(UserCommandFlag[CommNo]._EnergyTuneShift_npoint),
                 &(UserCommandFlag[CommNo]._EnergyTuneShift_nturn), 
	         &(UserCommandFlag[CommNo]._EnergyTuneShift_deltamax));
        
	strcpy(UserCommandFlag[CommNo].CommandStr,name);
	    
      }
      else if (strcmp("ErrorCouplingFlag", name) == 0){
        sscanf(line, "%*s  %ld %lf",&(UserCommandFlag[CommNo].err_seed),&(UserCommandFlag[CommNo].err_rms));
        strcpy(UserCommandFlag[CommNo].CommandStr,name);
      
      }
        else if (strcmp("ErrorCoupling2Flag", name) == 0){
        sscanf(line, "%*s  %ld %lf",&(UserCommandFlag[CommNo].err_seed),&(UserCommandFlag[CommNo].err_rms));
        strcpy(UserCommandFlag[CommNo].CommandStr,name);
        
      }
      else if (strcmp("CouplingFlag", name) == 0){
        strcpy(UserCommandFlag[CommNo].CommandStr,name);
        
      }//momentum compact factor
       else if (strcmp("MomentumAccFlag", name) == 0){
         sscanf(line, "%*s %s",nextpara);
	 
	 if(strcmp(nextpara,"voidpara")!=0){    
	   sscanf(line, "%*s  %s %s %ld %ld %lf %lf %ld %lf %lf %ld %ld %lf",
		      UserCommandFlag[CommNo]._MomentumAccFlag_momacc_file,
		      UserCommandFlag[CommNo]._MomentumAccFlag_TrackDim,
		      &(UserCommandFlag[CommNo]._MomentumAccFlag_istart),
		      &(UserCommandFlag[CommNo]._MomentumAccFlag_istop),
        	      &(UserCommandFlag[CommNo]._MomentumAccFlag_deltaminp),
		      &(UserCommandFlag[CommNo]._MomentumAccFlag_deltamaxp),
		      &(UserCommandFlag[CommNo]._MomentumAccFlag_nstepp),
        	      &(UserCommandFlag[CommNo]._MomentumAccFlag_deltaminn),
		      &(UserCommandFlag[CommNo]._MomentumAccFlag_deltamaxn),
		      &(UserCommandFlag[CommNo]._MomentumAccFlag_nstepn),
                      &(UserCommandFlag[CommNo]._MomentumAccFlag_nturn),
		      &(UserCommandFlag[CommNo]._MomentumAccFlag_zmax));
	 } 
	 strcpy(UserCommandFlag[CommNo].CommandStr,name);   
      }
   
//       generic one, fit for 1 family of quadrupoles
      else if (strcmp("FitTuneFlag", name) == 0){
        sscanf(line, "%*s %s %s %lf %lf",UserCommandFlag[CommNo].qf,UserCommandFlag[CommNo].qd,
	&(UserCommandFlag[CommNo].targetnux),&(UserCommandFlag[CommNo].targetnuz));
       strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }
      // fit for 2 families,specific for the soleil lattice in which the quadrupole is cut into 2 parts
       else if (strcmp("FitTune4Flag", name) == 0){
        sscanf(line, "%*s %s %s %s %s %lf %lf",UserCommandFlag[CommNo].qf1,UserCommandFlag[CommNo].qf2,
	UserCommandFlag[CommNo].qd1,UserCommandFlag[CommNo].qd2,
	&(UserCommandFlag[CommNo].targetnux),&(UserCommandFlag[CommNo].targetnuz));
        strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }
       else if (strcmp("FitChromFlag", name) == 0){
        sscanf(line, "%*s  %s %s %lf %lf",UserCommandFlag[CommNo].sxm1,UserCommandFlag[CommNo].sxm2,
	&(UserCommandFlag[CommNo].targetksix),&(UserCommandFlag[CommNo].targetksiz));
        strcpy(UserCommandFlag[CommNo].CommandStr,name);
      }
//       else if (strcmp("GirderErrorFlag", name) == 0){
//        strcpy(UserCommand[CommandNo-1],name);
//          // GirderErrorFlag = true;
//        
//       }
//        else if (strcmp("SigmaFlag", name) == 0){
//         strcpy(UserCommand[CommandNo-1],name);
//          // SigmaFlag = true;
//         
//       }
//        else if (strcmp("PX2Flag", name) == 0){
//        strcpy(UserCommand[CommandNo-1],name);
//          // PX2Flag = true;
//         
//       }
       else if (strcmp("InducedAmplitudeFlag", name) == 0){
        strcpy(UserCommandFlag[CommNo].CommandStr,name); 
      }
//        else if (strcmp("CodeComparaisonFlag", name) == 0){
//        strcpy(UserCommand[CommandNo-1],name);
//         //  CodeComparaisonFlag = true;
//        
//       }
       else if (strcmp("EtaFlag", name) == 0){
         strcpy(UserCommandFlag[CommNo].CommandStr,name); 
      }//phase space
       else if (strcmp("PhaseSpaceFlag", name) == 0) {
         sscanf(line, "%*s %s",nextpara);
	 //if the next para is not empty, then use the user set value, otherwise use default value
	 if(strcmp(nextpara,"voidpara") != 0){
	   sscanf(line, "%*s %s %s %lf %lf %lf %lf %lf %lf %ld %s", 
	               UserCommandFlag[CommNo]._Phase_phase_file,
	               UserCommandFlag[CommNo]._Phase_Dim,
                       &(UserCommandFlag[CommNo]._Phase_X), 
		       &(UserCommandFlag[CommNo]._Phase_Px), 
		       &(UserCommandFlag[CommNo]._Phase_Y), 
		       &(UserCommandFlag[CommNo]._Phase_Py), 
		       &(UserCommandFlag[CommNo]._Phase_delta),
                       &(UserCommandFlag[CommNo]._Phase_ctau), 
		       &(UserCommandFlag[CommNo]._Phase_nturn), 
		       str);
	 }
	 //radiation damping
          if (strcmp(str, "true") == 0)
            UserCommandFlag[CommNo]._Phase_Damping = true;
          else if (strcmp(str, "false") == 0)
            UserCommandFlag[CommNo]._Phase_Damping = false;
	
	 strcpy(UserCommandFlag[CommNo].CommandStr,name); 
      }
      //calculate Touschek lifetime
       else if (strcmp("TouschekFlag", name) == 0){
	  strcpy(UserCommandFlag[CommNo].CommandStr,name); 
       
      }//intra beam scattering
       else if (strcmp("IBSFlag", name) == 0){
        strcpy(UserCommandFlag[CommNo].CommandStr,name); 
      }//momentum acceptance is got by tracking, then cal touschek lifetime
       else if (strcmp("TousTrackFlag", name) == 0){
        strcpy(UserCommandFlag[CommNo].CommandStr,name); 
      }
      //bpms and h/v correctors used for orbit correction
      else if (strcmp("bpm_name", name) == 0){ 
        sscanf(line, "%*s %s", bpm_name); /* the name of bpm */
      }
      else if (strcmp("h_corr", name) == 0){ 
        sscanf(line, "%*s %s", hcorr_name); /* the name of H corrector used for COD correction*/
      }
      else if (strcmp("v_corr", name) == 0){ 
        sscanf(line, "%*s %s", vcorr_name); /* the name of V corrector used for COD correction*/
      }
      else if (strcmp("qt", name) == 0){ 
        sscanf(line, "%*s %s", skew_quad_name); /* name of skew quadrupoles */
      }
      else if (strcmp("gs", name) == 0){ 
        sscanf(line, "%*s %s", gs_name); /* name of start of the girder */
      }
      else if (strcmp("ge", name) == 0){ 
        sscanf(line, "%*s %s", ge_name); /* name of end of the girder */
      }
      else if (strcmp("normalcut", name) == 0){
        sscanf(line, "%*s %d", &idummy);
        fprintf(stdout,"User value for cutting at n sigma-s the normal distributions\n");
        setrancut(idummy); /* set normal cut for computation: random data are n sigma-s*/
      }
      //flag to do orbit correction
      else if (strcmp("CODCorrectFlag", name) == 0){
        strcpy(UserCommandFlag[CommNo].CommandStr,name);
      } 
      //set parameters for COD correction
      else if (strcmp("n_orbit", name) == 0){
        sscanf(line, "%*s %d", &n_orbit);
      }
      else if (strcmp("nwh", name) == 0){
        sscanf(line, "%*s %d", &nwh);
      }
      else if (strcmp("nwv", name) == 0){
        sscanf(line, "%*s %d", &nwv);
      }
       else if (strcmp("hcorr_file", name) == 0){ 
        sscanf(line, "%*s %s", str);
        sprintf(hcorr_file,"%s%s", in_dir, str); /* add file directory*/
      }
       else if (strcmp("vcorr_file", name) == 0){ 
        sscanf(line, "%*s %s", str);
        sprintf(vcorr_file,"%s%s", in_dir, str); /* add file directory*/
      }
      //ID correction
      else if (strcmp("IDCorrFlag", name) == 0)
        strcpy(UserCommandFlag[CommNo].CommandStr,name); 
      else if (strcmp("scl_dbetax", name) == 0)//scaling of dbetax, for ID correction
	sscanf(line, "%*s %lf", &scl_dbetax); 
      else if (strcmp("scl_dbetay", name) == 0)//scaling of dbetay, for ID correction
	sscanf(line, "%*s %lf", &scl_dbetay); 
      else if (strcmp("scl_dnux", name) == 0)//scaling of dnux, for ID correction
	sscanf(line, "%*s %lf", &scl_dnux); 
      else if (strcmp("scl_dnuy", name) == 0)//scaling of dnuy, for ID correction
	sscanf(line, "%*s %lf", &scl_dnuy); 
      else if (strcmp("scl_nux", name) == 0) //scaling of nux, for ID correction
	sscanf(line, "%*s %lf", &scl_nux); 
      else if (strcmp("scl_nuy", name) == 0) //scaling of nuy, for ID correction
	sscanf(line, "%*s %lf", &scl_nuy); 
      else if (strcmp("ID_step", name) == 0)//ID steps, for ID correction
	sscanf(line, "%*s %lf", &ID_step); 
      else if (strcmp("N_calls", name) == 0) // ID correction parameters
	sscanf(line, "%*s %d", &N_calls);
      else if (strcmp("N_steps", name) == 0)
	sscanf(line, "%*s %d", &N_steps);
      else if (strcmp("N_Fam", name) == 0)
	sscanf(line, "%*s %d", &N_Fam);
      else if (strcmp("IDCquads", name) == 0) {
	sscanf(line, "%*s %s %s %s %s %s %s %s %s %s %s %s",
	       IDCq_name[0], IDCq_name[1], IDCq_name[2], IDCq_name[3],
	       IDCq_name[4], IDCq_name[5], IDCq_name[6], IDCq_name[7],
	       IDCq_name[8], IDCq_name[9], IDCq_name[10]);
      }
      else{
        printf("bad line in file %s, line %ld \n", full_param_file_name, LineNum);
        exit_(1);
      }
    }
    /* continue read in the line */ 
    else
      continue;
  }
  fclose(inf);
}  
 
